@@ -76,6 +76,7 @@ class OdrStop(Exception):
     """
     pass
 
+
 # Backwards compatibility
 odr_error = OdrError
 odr_stop = OdrStop
@@ -306,7 +307,7 @@ class RealData(Data):
         If array-like, observed data for the dependent variable of the
         regression. A scalar input implies that the model to be used on
         the data is implicit.
-    sx, sy : array_like, optional
+    sx : array_like, optional
         Standard deviations of `x`.
         `sx` are standard deviations of `x` and are converted to weights by
         dividing 1.0 by their squares.
@@ -563,7 +564,7 @@ class Output(object):
         Array ``y = fcn(x + delta)``.
     res_var : float, optional
         Residual variance.
-    sum_sqare : float, optional
+    sum_square : float, optional
         Sum of squares error.
     sum_square_delta : float, optional
         Sum of squares of delta error.
@@ -1056,7 +1057,7 @@ class ODR(object):
         self.iprint = ip[0]*1000 + ip[1]*100 + ip[2]*10 + ip[3]
 
     def run(self):
-        """ Run the fitting routine with all of the information given.
+        """ Run the fitting routine with all of the information given and with ``full_output=1``.
 
         Returns
         -------
